#[repr(C)]pub struct mpv_render_param {
pub type_: mpv_render_param_type,
pub data: *mut c_void,
}Expand description
Used to pass arbitrary parameters to some mpv_render_* functions. The meaning of the data parameter is determined by the type, and each MPV_RENDER_PARAM_* documents what type the value must point to.
Each value documents the required data type as the pointer you cast to void* and set on mpv_render_param.data. For example, if MPV_RENDER_PARAM_FOO documents the type as Something* , then the code should look like this:
Something foo = {…}; mpv_render_param param; param.type = MPV_RENDER_PARAM_FOO; param.data = & foo;
Normally, the data field points to exactly 1 object. If the type is char*, it points to a 0-terminated string.
In all cases (unless documented otherwise) the pointers need to remain valid during the call only. Unless otherwise documented, the API functions will not write to the params array or any data pointed to it.
As a convention, parameter arrays are always terminated by type==0. There is no specific order of the parameters required. The order of the 2 fields in this struct is guaranteed (even after ABI changes).
Fields
type_: mpv_render_param_typedata: *mut c_voidTrait Implementations
Sourceimpl Clone for mpv_render_param
impl Clone for mpv_render_param
Sourcefn clone(&self) -> mpv_render_param
fn clone(&self) -> mpv_render_param
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for mpv_render_param
impl Debug for mpv_render_param
impl Copy for mpv_render_param